@@ -20,7 +20,7 @@
     config.tape.parallel      = true;
     \endcode
 */
-static struct config_struct{
+struct config_struct{
   /* Configuration variables.
      - Default values _must_be_ specified with SET(var,value) 
      - Can be either bool or integer.
@@ -43,16 +43,18 @@ static struct config_struct{
 
   int cmd;
   SEXP envir;
-  void set(const char* name, bool &var, bool default_value){
+  void set(const char* name, bool &var, bool default_value) CSKIP(
+  {
     // cmd=0: set defaults in this struct.
     // cmd=1: copy from this struct to R.
     // cmd=2: copy from R to this struct.
     if(cmd==0)var=default_value;
     if(cmd==1)defineVar(install(name),asSEXP(var),envir);
     if(cmd==2)var=INTEGER(findVar(install(name),envir))[0];
-  }
+  })
 #define SET(name,value)set(#name,name,value);
-  void set(){
+  void set() CSKIP(
+  {
     SET(trace.parallel,true);
     SET(trace.optimize,true);
     SET(trace.atomic,true);
@@ -60,20 +62,23 @@ static struct config_struct{
     SET(optimize.instantly,true);
     SET(optimize.parallel,false);
     SET(tape.parallel,true);
-  }
+  })
 #undef SET
-  config_struct(){
+  config_struct() CSKIP(
+  {
     cmd=0;
     set();
-  };
-} config;
+  })
+};
+TMB_EXTERN config_struct config;
 
 extern "C"
 {
-  SEXP TMBconfig(SEXP envir, SEXP cmd){
+  SEXP TMBconfig(SEXP envir, SEXP cmd) CSKIP(
+  {
     config.cmd=INTEGER(cmd)[0];
     config.envir=envir;
     config.set();
     return R_NilValue;
-  }
+  })
 }
